summaryrefslogtreecommitdiff
path: root/tests/pm_rps.c
diff options
context:
space:
mode:
authorMicah Fedke <micah.fedke@collabora.co.uk>2015-07-22 21:54:02 +0000
committerThomas Wood <thomas.wood@intel.com>2015-09-11 14:39:43 +0100
commitc81d293aed94fea9c48899187016a1b28f8989d5 (patch)
tree7d7fd67c9f8eb843b799111e8cf0776829cd585e /tests/pm_rps.c
parente2241805a43e2cbd5287010e90005542845b48cd (diff)
convert drm_open_any*() calls to drm_open_driver*(DRIVER_INTEL) calls with cocci
Apply the new API to all call sites within the test suite using the following semantic patch: // Semantic patch for replacing drm_open_any* with arch-specific drm_open_driver* calls @@ identifier i =~ "\bdrm_open_any\b"; @@ - i() + drm_open_driver(DRIVER_INTEL) @@ identifier i =~ "\bdrm_open_any_master\b"; @@ - i() + drm_open_driver_master(DRIVER_INTEL) @@ identifier i =~ "\bdrm_open_any_render\b"; @@ - i() + drm_open_driver_render(DRIVER_INTEL) @@ identifier i =~ "\b__drm_open_any\b"; @@ - i() + __drm_open_driver(DRIVER_INTEL) Signed-off-by: Micah Fedke <micah.fedke@collabora.co.uk> Signed-off-by: Thomas Wood <thomas.wood@intel.com>
Diffstat (limited to 'tests/pm_rps.c')
-rw-r--r--tests/pm_rps.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/pm_rps.c b/tests/pm_rps.c
index ccc67185..74f08f47 100644
--- a/tests/pm_rps.c
+++ b/tests/pm_rps.c
@@ -606,7 +606,7 @@ static void blocking(void)
int pre_freqs[NUMFREQ];
int post_freqs[NUMFREQ];
- int fd = drm_open_any();
+ int fd = drm_open_driver(DRIVER_INTEL);
igt_assert_lte(0, fd);
/*
@@ -661,8 +661,8 @@ igt_main
struct junk *junk = stuff;
int ret;
- /* Use drm_open_any to verify device existence */
- drm_fd = drm_open_any();
+ /* Use drm_open_driver to verify device existence */
+ drm_fd = drm_open_driver(DRIVER_INTEL);
do {
int val = -1;